@@ -23,12 +23,12 @@ use strict;
 #-----------------------------------------------------------------
 
 my %REGISTRIES =
-    ( iCAPTURE => { endpoint  => 'http://mobycentral.icapture.ubc.ca/cgi-bin/MOBY05/mobycentral.pl',
-		    namespace => 'http://mobycentral.icapture.ubc.ca/MOBY/Central',
-		    name      => 'iCAPTURE Centre, Vancouver',
+    ( MainRegistry => { endpoint  => 'http://moby.ucalgary.ca/moby/MOBY-Central.pl',
+		    namespace => 'http://moby.ucalgary.ca/MOBY/Central',
+		    name      => 'Sun Centre of Excellence, Calgary',
 		    contact   => 'Edward Kawas (edward.kawas@gmail.com)',
 		    public    => 'yes',
-		    text      => 'A curated public registry hosted at the iCAPTURE Centre, Vancouver',
+		    text      => 'A curated main public registry hosted at ucalgary, Calgary',
 		},
       IRRI     => { endpoint  => 'http://cropwiki.irri.org/cgi-bin/MOBY-Central.pl',
 		    namespace => 'http://cropwiki.irri.org/MOBY/Central',
@@ -45,7 +45,7 @@ my %REGISTRIES =
 		},
       );
 
-$REGISTRIES{default} = $REGISTRIES{iCAPTURE};
+$REGISTRIES{default} = $REGISTRIES{MainRegistry};
 
 #-----------------------------------------------------------------
 # init
